# Generated by Django 2.1.7 on 2019-03-08 16:03

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Todo',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('owner', models.CharField(max_length=30)),
                ('title', models.CharField(max_length=30)),
                ('status', models.CharField(choices=[('N', 'Todo'), ('P', 'In Progress'), ('D', 'Done')], max_length=30)),
                ('size', models.PositiveIntegerField(default=1)),
                ('due', models.DateField()),
                ('due_time', models.DateTimeField()),
            ],
        ),
    ]
