# Generated by Django 3.0.3 on 2020-02-25 23:49

import django.contrib.postgres.fields.jsonb
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='ActionEvent',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('action_id', models.CharField(max_length=100)),
                ('actor_id', models.CharField(blank=True, max_length=100, null=True)),
                ('object_id', models.CharField(blank=True, max_length=100, null=True)),
                ('action_context', models.CharField(blank=True, max_length=30, null=True)),
                ('status_code', models.PositiveIntegerField(default=0)),
                ('request_data', django.contrib.postgres.fields.jsonb.JSONField(blank=True, null=True)),
                ('response_data', django.contrib.postgres.fields.jsonb.JSONField(blank=True, null=True)),
                ('response_content', models.TextField(blank=True, null=True)),
                ('complete', models.BooleanField(default=False)),
                ('duration', models.DecimalField(decimal_places=10, default=0, max_digits=14)),
                ('scheduled_time', models.DateTimeField(blank=True, null=True)),
                ('created_date', models.DateTimeField(auto_now_add=True, db_index=True)),
                ('modified_date', models.DateTimeField(auto_now=True, db_index=True)),
            ],
        ),
    ]
